@@ -120,6 +120,22 @@ terminal_cursor_shape_get_type (void)
   }
 	return type;
 }
+GType
+terminal_text_blink_mode_get_type (void)
+{
+	static GType type = 0;
+	if (type == 0) {
+	static const GEnumValue values[] = {
+ 	{ TERMINAL_TEXT_BLINK_MODE_NEVER, "TERMINAL_TEXT_BLINK_MODE_NEVER", "never" },
+ 	{ TERMINAL_TEXT_BLINK_MODE_FOCUSED, "TERMINAL_TEXT_BLINK_MODE_FOCUSED", "focused" },
+ 	{ TERMINAL_TEXT_BLINK_MODE_UNFOCUSED, "TERMINAL_TEXT_BLINK_MODE_UNFOCUSED", "unfocused" },
+ 	{ TERMINAL_TEXT_BLINK_MODE_ALWAYS, "TERMINAL_TEXT_BLINK_MODE_ALWAYS", "always" },
+ 	{ 0, NULL, NULL }
+	};
+	type = g_enum_register_static ("TerminalTextBlinkMode", values);
+  }
+	return type;
+}
 
 
 
