@@ -137,20 +137,19 @@ terminal_tab_attr_free (TerminalTabAttr *attr)
   g_free (attr->directory);
   g_free (attr->title);
   g_free (attr->initial_title);
+  g_free (attr->color_text);
+  g_free (attr->color_bg);
   g_slice_free (TerminalTabAttr, attr);
 }
 
 
 
 void
-terminal_options_parse (gint       argc,
-                        gchar    **argv,
-                        gboolean  *show_help,
-                        gboolean  *show_version,
-                        gboolean  *show_colors,
-                        gboolean  *disable_server)
+terminal_options_parse (gint              argc,
+                        gchar           **argv,
+                        TerminalOptions  *options)
 {
-  gint   n;
+  gint n;
 
   for (n = 1; n < argc; ++n)
     {
@@ -163,13 +162,15 @@ terminal_options_parse (gint       argc,
         break;
 
       if (terminal_option_cmp ("help", 'h', argc, argv, &n, NULL))
-        *show_help = TRUE;
+        options->show_help = TRUE;
       else if (terminal_option_cmp ("version", 'V', argc, argv, &n, NULL))
-        *show_version = TRUE;
+        options->show_version = TRUE;
       else if (terminal_option_cmp ("disable-server", 0, argc, argv, &n, NULL))
-        *disable_server = TRUE;
+        options->disable_server = TRUE;
       else if (terminal_option_cmp ("color-table", 0, argc, argv, &n, NULL))
-        *show_colors = TRUE;
+        options->show_colors = TRUE;
+      else if (terminal_option_cmp ("preferences", 0, argc, argv, &n, NULL))
+        options->show_preferences = TRUE;
     }
 }
 
@@ -351,13 +352,55 @@ terminal_window_attr_parse (gint              argc,
         {
           tab_attr->hold = TRUE;
         }
+      else if (terminal_option_cmp ("active-tab", 0, argc, argv, &n, NULL))
+        {
+          tab_attr->active = TRUE;
+        }
+      else if (terminal_option_cmp ("color-text", 0, argc, argv, &n, &s))
+        {
+          GdkRGBA color;
+          if (G_UNLIKELY (s == NULL))
+            {
+              g_set_error (error, G_SHELL_ERROR, G_SHELL_ERROR_FAILED,
+                           _("Option \"%s\" requires specifying "
+                             "the color as its parameter"), "--color-text");
+              goto failed;
+            }
+          else if (!gdk_rgba_parse (&color, s))
+            {
+              g_set_error (error, G_SHELL_ERROR, G_SHELL_ERROR_FAILED,
+                           _("Unable to parse color: %s"), s);
+              goto failed;
+            }
+          g_free (tab_attr->color_text);
+          tab_attr->color_text = g_strdup (s);
+        }
+      else if (terminal_option_cmp ("color-bg", 0, argc, argv, &n, &s))
+        {
+          GdkRGBA color;
+          if (G_UNLIKELY (s == NULL))
+            {
+              g_set_error (error, G_SHELL_ERROR, G_SHELL_ERROR_FAILED,
+                           _("Option \"%s\" requires specifying "
+                             "the color as its parameter"), "--color-bg");
+              goto failed;
+            }
+          else if (!gdk_rgba_parse (&color, s))
+            {
+              g_set_error (error, G_SHELL_ERROR, G_SHELL_ERROR_FAILED,
+                           _("Unable to parse color: %s"), s);
+              goto failed;
+            }
+          g_free (tab_attr->color_bg);
+          tab_attr->color_bg = g_strdup (s);
+        }
       else if (terminal_option_cmp ("display", 0, argc, argv, &n, &s))
         {
           if (G_UNLIKELY (s == NULL))
             {
               g_set_error (error, G_SHELL_ERROR, G_SHELL_ERROR_FAILED,
                            _("Option \"--display\" requires specifying "
-                             "the X display as its parameters"));
+                             "the X display as its parameter"));
               goto failed;
             }
           else
@@ -622,8 +665,7 @@ terminal_window_attr_free (TerminalWindowAttr *attr)
 {
   terminal_return_if_fail (attr != NULL);
 
-  g_slist_foreach (attr->tabs, (GFunc) terminal_tab_attr_free, NULL);
-  g_slist_free (attr->tabs);
+  g_slist_free_full (attr->tabs, (GDestroyNotify) terminal_tab_attr_free);
   g_free (attr->startup_id);
   g_free (attr->sm_client_id);
   g_free (attr->geometry);
