@@ -58,8 +58,11 @@ typedef struct
   gchar        *directory;
   gchar        *title;
   gchar        *initial_title;
+  gchar        *color_text;
+  gchar        *color_bg;
   TerminalTitle dynamic_title_mode;
   guint         hold : 1;
+  guint         active : 1;
 } TerminalTabAttr;
 
 typedef struct
@@ -84,12 +87,18 @@ typedef struct
   TerminalZoomLevel    zoom;
 } TerminalWindowAttr;
 
+typedef struct
+{
+  gboolean show_help;
+  gboolean show_version;
+  gboolean show_colors;
+  gboolean show_preferences;
+  gboolean disable_server;
+} TerminalOptions;
+
 void                terminal_options_parse     (gint                 argc,
                                                 gchar              **argv,
-                                                gboolean            *show_help,
-                                                gboolean            *show_version,
-                                                gboolean            *show_colors,
-                                                gboolean            *disable_server);
+                                                TerminalOptions     *options);
 
 GSList             *terminal_window_attr_parse (gint                 argc,
                                                 gchar              **argv,
